<p align="center"><img src="https://github.com/Adri-Hdez/Pipeln/blob/main/doc/static/img/pipeln_logo_x2.png" alt="logo" width="80%" /></p>

<p align="center">
 <i>A package to create a custom pipeline</i>
</p>


----------------------

# Installation & Upgrade

- Installation: `pip install pipeln`
- Upgrade: `pip install pipeln --upgrade`

For the correct usage, `from Pipeln.pipeline import Pipeline` this is our principal `Object`. For more information you can call `info()` method. Through `Pipeline` you can call `build` method and create/run your own project pipeline.

<p><i>Im still implementing new features...</i><p>

# License
Preln is licensed under [MIT License](LICENSE).

# Shields
<p align="center">
  <a href="https://pypi.org/project/pipeln/">
    <img src="https://img.shields.io/pypi/v/pipeln" alt="PyPI" />
  </a>
  <a href="https://pepy.tech/project/pipeln">
    <img src="https://pepy.tech/badge/pipeln/month" alt="downloads" />
  </a>
</p>
